;; Generated package description from diff-hl.el  -*- no-byte-compile: t -*-
(define-package "diff-hl" "1.10.0.0.20241205.233841" "Highlight uncommitted changes using VC" '((cl-lib "0.2") (emacs "25.1")) :commit "65a5de16e21c87b7c12a78a63fc3b57e07c03c86" :authors '(("Dmitry Gutov" . "dmitry@gutov.dev")) :maintainer '("Dmitry Gutov" . "dmitry@gutov.dev") :keywords '("vc" "diff") :url "https://github.com/dgutov/diff-hl")
